@@ -12,10 +12,11 @@ logger = logging.getLogger('VERSIONNING')
 import unicodedata
 
 class Repository(object):
-    def __init__(self, repo_folder):
+    def __init__(self, repo_folder, default_user="process"):
         self.repo_folder = repo_folder
         self.repo_ui = ui.ui()
         self.repo = None
+        self.default_user = default_user
         self.init_repo()
         
     def init_repo(self):
@@ -40,7 +41,10 @@ class Repository(object):
         
         logger.info('Commiting initial data in repo.')
         
-        commands.commit(self.repo_ui, self.repo, message="initial import")
+        commands.commit(self.repo_ui,
+                        self.repo,
+                        message="initial import",
+                        user=self.default_user)
         
     def get_entityname(self, item):
         return str(item.__class__).split('.')[-1][:-2].lower()
@@ -101,7 +105,7 @@ class Repository(object):
                 self.send_object_change(item)
             
     def store_item(self, item, user=None):
-        self.__store_item(item, commit=True, user=user)
+        self.__store_item(item, commit=True, user=(user or self.default_user))
         
     def delete_item(self, item, user=None):
         file_path = self.get_filepath(item)
@@ -115,7 +119,7 @@ class Repository(object):
                             message='deleting %s "%s"' % \
                                     (self.get_entityname(item),
                                      self.get_obj_name(item)),
-                            user=user)
+                            user=(user or self.default_user))
         
     def __store_item(self, item, commit=False, user=None):
         file_content = self.get_file_content(item)
